==> open-xchange-mobile-api-facade_1.0.0.orig.tar.bz2: open-xchange-mobile-api-facade-1.0.0/com.openexchange.mobile.api.facade/src/com/openexchange/mobile/api/facade/exceptions/ApiFacadeException.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mobile.api.facade.exceptions;

import javax.ws.rs.WebApplicationException;
import javax.ws.rs.core.Response;
import javax.ws.rs.core.Response.Status;

import com.openexchange.mobile.api.facade.connectors.AbstractResponseMto;
import com.openexchange.mobile.api.facade.endpoints.responses.AbstractResponseBody;
import com.openexchange.mobile.api.facade.utils.JacksonUtil;
import com.openexchange.mobile.api.facade.utils.StringUtils;

import lombok.Getter;

@SuppressWarnings("serial")
public class ApiFacadeException extends WebApplicationException {

    public interface Code {

        int INVALID_CREDENTIALS = 1;

        int MISSING_HEADER = 2;

        int MISSING_PARAMETER = 3;

        int MISSING_COOKIES = 4;

        int INVALID_USER_AGENT = 5;

        String INVALID_SESSION = "SES-206";

        int CLIENT_UPDATE_MANDATORY = 900;

        int INTERNAL_SERVER_ERROR = 999;

    }

    @Getter
    private String errorCode;

    private ApiFacadeException(String errorCode, Exception cause, String message, Response response) {
        super(message, cause, response);
        this.errorCode = errorCode;
    }

    public static ApiFacadeException fromResponseBody(AbstractResponseMto responseBody) {
        String code = responseBody.getCode();
        String error = responseBody.getError();
        if (isSessionInvalid(code, error)) {
            return invalidSession();
        } else if (areCredentialsInvalid(code)) {
            return invalidCredentials();
        }
        return create(Status.BAD_REQUEST, code, responseBody.getErrorDescription());
    }

    private static boolean isSessionInvalid(String code, String error) {
        return (!StringUtils.isEmpty(code) && code.startsWith("SES-"))
                || (!StringUtils.isEmpty(error) && error.startsWith("SES-"));
    }

    private static boolean areCredentialsInvalid(String code) {
        return "MSG-1000".equals(code);
    }

    public static ApiFacadeException badRequest(int errorCode, String message) {
        return create(Status.BAD_REQUEST, errorCode, message);
    }

    public static ApiFacadeException invalidCredentials() {
        return create(Status.UNAUTHORIZED, Code.INVALID_CREDENTIALS, "Username/password invalid");
    }

    public static ApiFacadeException invalidSession() {
        return create(Status.UNAUTHORIZED, Code.INVALID_SESSION, "Your session was invalidated. Please try again.");
    }

    public static ApiFacadeException missingHeader(String name) {
        return create(Status.BAD_REQUEST, Code.MISSING_HEADER, "Header missing: " + name);
    }

    public static ApiFacadeException missingParameter(String name) {
        return create(Status.BAD_REQUEST, Code.MISSING_PARAMETER, "Parameter missing: " + name);
    }

    public static ApiFacadeException invalidUserAgent() {
        return create(Status.BAD_REQUEST, Code.INVALID_USER_AGENT, "Invalid User-Agent header");
    }

    public static ApiFacadeException authenticationNotFound() {
        return internalServerError("Authentication mechanism not found");
    }

    public static ApiFacadeException internalServerError(String message) {
        return create(Status.INTERNAL_SERVER_ERROR, Code.INTERNAL_SERVER_ERROR, message);
    }

    public static ApiFacadeException internalServerError(Exception cause) {
        if (cause instanceof ApiFacadeException) {
            return (ApiFacadeException) cause;
        }
        String message = cause.getMessage() != null ? cause.getMessage() : cause.getClass().getName();
        return create(Status.INTERNAL_SERVER_ERROR, Code.INTERNAL_SERVER_ERROR, cause, message);
    }

    public static ApiFacadeException clientUpdateMandatory() {
        return create(Status.GONE, Code.CLIENT_UPDATE_MANDATORY, "Client too old. Please update");
    }

    private static ApiFacadeException create(Status status, int errorCode, String message) {
        return create(status, String.valueOf(errorCode), message);
    }

    private static ApiFacadeException create(Status status, int errorCode, Exception cause, String message) {
        return create(status, String.valueOf(errorCode), cause, message);
    }

    private static ApiFacadeException create(Status status, String errorCode, String message) {
        return create(status, errorCode, null, message);
    }

    private static ApiFacadeException create(Status status, String errorCode, Exception cause, String message) {
        String responseBody = JacksonUtil.toString(new AbstractResponseBody(errorCode, message));
        Response response = Response.status(status).entity(responseBody).build();
        return new ApiFacadeException(errorCode, cause, message, response);
    }

    public static Exception weakforceInvalidHashAlgorithm(String algorithm) {
        return create(Status.INTERNAL_SERVER_ERROR, Code.INTERNAL_SERVER_ERROR, "Hashing algorithm not supported: " + algorithm);
    }

}

==> open-xchange-mobile-api-facade_1.0.3.orig.tar.bz2: open-xchange-mobile-api-facade-1.0.3/com.openexchange.mobile.api.facade/src/com/openexchange/mobile/api/facade/exceptions/ApiFacadeException.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mobile.api.facade.exceptions;

import javax.ws.rs.WebApplicationException;
import javax.ws.rs.core.Response;
import javax.ws.rs.core.Response.Status;

import com.openexchange.mobile.api.facade.connectors.AbstractResponseMto;
import com.openexchange.mobile.api.facade.endpoints.responses.AbstractResponseBody;
import com.openexchange.mobile.api.facade.utils.JacksonUtil;
import com.openexchange.mobile.api.facade.utils.StringUtils;

import lombok.Getter;

@SuppressWarnings("serial")
public class ApiFacadeException extends WebApplicationException {

    public interface Code {

        int INVALID_CREDENTIALS = 1;

        int MISSING_HEADER = 2;

        int MISSING_PARAMETER = 3;

        int MISSING_COOKIES = 4;

        int INVALID_USER_AGENT = 5;

        int MAXIMUM_NUMBER_OF_SESSIONS_EXCEEDED = 6;

        String INVALID_SESSION = "SES-206";

        int CLIENT_UPDATE_MANDATORY = 900;

        int INTERNAL_SERVER_ERROR = 999;

    }

    @Getter
    private String errorCode;

    private ApiFacadeException(String errorCode, Exception cause, String message, Response response) {
        super(message, cause, response);
        this.errorCode = errorCode;
    }

    public static ApiFacadeException fromResponseBody(AbstractResponseMto responseBody) {
        String code = responseBody.getCode();
        String error = responseBody.getError();
        if (isMaximumNumberOfSessionsExceeded(code)) {
            return maximumNumberOfSessionsExceeded();
        } else if (isSessionInvalid(code, error)) {
            return invalidSession();
        } else if (areCredentialsInvalid(code)) {
            return invalidCredentials();
        }
        return create(Status.BAD_REQUEST, code, responseBody.getErrorDescription());
    }

    private static boolean isMaximumNumberOfSessionsExceeded(String code) {
        return "SES-0007".equals(code);
    }

    private static boolean isSessionInvalid(String code, String error) {
        return (!StringUtils.isEmpty(code) && code.startsWith("SES-"))
                || (!StringUtils.isEmpty(error) && error.startsWith("SES-"));
    }

    private static boolean areCredentialsInvalid(String code) {
        return "MSG-1000".equals(code) || "LGI-0006".equals(code);
    }

    public static ApiFacadeException badRequest(int errorCode, String message) {
        return create(Status.BAD_REQUEST, errorCode, message);
    }

    public static ApiFacadeException invalidCredentials() {
        return create(Status.UNAUTHORIZED, Code.INVALID_CREDENTIALS, "Username/password invalid");
    }

    public static ApiFacadeException maximumNumberOfSessionsExceeded() {
        return create(Status.UNAUTHORIZED, Code.MAXIMUM_NUMBER_OF_SESSIONS_EXCEEDED, "Maximum number of sessions exceeded for your account. Please logout from other clients and try again.");
    }

    public static ApiFacadeException invalidSession() {
        return create(Status.UNAUTHORIZED, Code.INVALID_SESSION, "Your session was invalidated. Please try again.");
    }

    public static ApiFacadeException missingHeader(String name) {
        return create(Status.BAD_REQUEST, Code.MISSING_HEADER, "Header missing: " + name);
    }

    public static ApiFacadeException missingParameter(String name) {
        return create(Status.BAD_REQUEST, Code.MISSING_PARAMETER, "Parameter missing: " + name);
    }

    public static ApiFacadeException invalidUserAgent() {
        return create(Status.BAD_REQUEST, Code.INVALID_USER_AGENT, "Invalid User-Agent header");
    }

    public static ApiFacadeException authenticationNotFound() {
        return internalServerError("Authentication mechanism not found");
    }

    public static ApiFacadeException internalServerError(String message) {
        return create(Status.INTERNAL_SERVER_ERROR, Code.INTERNAL_SERVER_ERROR, message);
    }

    public static ApiFacadeException internalServerError(Exception cause) {
        if (cause instanceof ApiFacadeException) {
            return (ApiFacadeException) cause;
        }
        String message = cause.getMessage() != null ? cause.getMessage() : cause.getClass().getName();
        return create(Status.INTERNAL_SERVER_ERROR, Code.INTERNAL_SERVER_ERROR, cause, message);
    }

    public static ApiFacadeException clientUpdateMandatory() {
        return create(Status.GONE, Code.CLIENT_UPDATE_MANDATORY, "Client too old. Please update");
    }

    private static ApiFacadeException create(Status status, int errorCode, String message) {
        return create(status, String.valueOf(errorCode), message);
    }

    private static ApiFacadeException create(Status status, int errorCode, Exception cause, String message) {
        return create(status, String.valueOf(errorCode), cause, message);
    }

    private static ApiFacadeException create(Status status, String errorCode, String message) {
        return create(status, errorCode, null, message);
    }

    private static ApiFacadeException create(Status status, String errorCode, Exception cause, String message) {
        String responseBody = JacksonUtil.toString(new AbstractResponseBody(errorCode, message));
        Response response = Response.status(status).entity(responseBody).build();
        return new ApiFacadeException(errorCode, cause, message, response);
    }

    public static Exception weakforceInvalidHashAlgorithm(String algorithm) {
        return create(Status.INTERNAL_SERVER_ERROR, Code.INTERNAL_SERVER_ERROR, "Hashing algorithm not supported: " + algorithm);
    }

}
